    class Application < Quickfix::Application

            def onCreate(sessionID)
            end

            def onLogon(sessionID)
            end

            def onLogout(sessionID)
            end

            def toAdmin(sessionID, message)
            end

            def toApp(sessionID, message)
            end

            def fromAdmin(sessionID, message)
            end

            def fromApp(sessionID, message)
            end

    end